@@ -5,7 +5,7 @@ from py4ami.constants import PHYSCHEM_PYTHON
 from py4ami.util import Util
 from py4ami.text_lib import AmiSection
 from py4ami.ami_dict import AmiDictionaries
-from py4ami.projects import AmiProjects
+from py4ami.ami_project import AmiProjects
 from py4ami.text_lib import WordFilter
 from py4ami.search_lib import AmiSearch
 
