@@ -66,6 +66,7 @@ class PyAMI:
     SYSTEM_EXIT_OK = "SystemExitOK"
     SYSTEM_EXIT_FAIL = "SystemExitFail_"
     TEST = "test"
+    VERSION = "version"
     WIKIDATA_SPARQL = "wikidata_sparql"
     XPATH = "xpath"
     # apply methods 1:1 input-output
@@ -181,7 +182,7 @@ class PyAMI:
         # apply_choices = [self.PDF2TXT, self.PDF2SVG, self.SVG2XML, self.TXT2SENT, self.XML2HTML, self.XML2TXT]
         apply_choices = ConvType.list_values()
         self.logger.debug(f"ch {apply_choices}")
-        parser.add_argument('--version', action="store_true",
+        parser.add_argument('-v', '--version', action="store_true",
                             help=f"show version {version}")
         parser.formatter_class = argparse.RawDescriptionHelpFormatter
         parser.description = textwrap.dedent(
@@ -429,6 +430,9 @@ class PyAMI:
 
     def run_core_mathods(self):
         logging.debug(f"run_core")
+        # mainly obsolete
+        if self.VERSION in self.args and self.args[self.VERSION] is not None:
+            self.print_version()
         if self.FLAGS in self.args and self.args[self.FLAGS] is not None:
             self.add_flags()
         if self.CONFIG in self.args and self.args[self.CONFIG] is not None:
@@ -444,11 +448,16 @@ class PyAMI:
         if self.PROJ in self.args:
             if self.SECT in self.args or self.GLOB in self.args or self.SPLIT in self.args:
                 self.run_project_workflow()
+        if self.VERSION in self.args:
+            self.print_version()
         # elif TestFile.TEST in self.args:
         #     self.logger.warning(f"TEST in **args {self.args}")
         #     TestFile.run_arg_tests(self.args)
         # TODO linkup with test arguments
 
+    def print_version(self):
+        print(f"version {self.version()}")
+
     def replace_single_values_in_self_args_with_list(self, key):
         """always returns list even for single arg
         e.g. turns "foo" into ["foo"]
@@ -1171,21 +1180,22 @@ class PyAMI:
             return False
 
     def version(self):
-        """reads setup.py and extracts line of form version='0.0.29'"""
-        import pkg_resources  # part of setuptools
-        version = pkg_resources.require("py4ami")[0].version
-        return version
+        """
+        reads setup.py and extracts line of form version='0.0.29'
+        This is still a mess. We need to set the versiom once somewhere.
+        """
 
-        # version = None
-        # with open(Path(Path(__file__).parent.parent, "setup.py"), "r") as f:
-        #     setup_lines = f.readlines()
-        #     for line in setup_lines:
-        #         match = re.match("\s*version\s*=\s*\'\s*(\d+\.\d+\.\d+)\s*\'\s*,", line)
-        #         if match:
-        #             version = match.group(1)
-        #             break
-        # print(f"VERSION {version}")
-        # return version
+        version = '0.0.45'
+        if False: # this fails - it gets the python distrib
+            with open(Path(Path(__file__).parent.parent, "setup.py"), "r") as f:
+                setup_lines = f.readlines()
+                for line in setup_lines:
+                    match = re.match("\s*version\s*=\s*\'\s*(\d+\.\d+\.\d+)\s*\'\s*,", line)
+                    if match:
+                        version = match.group(1)
+                        break
+        # logging.warn(f"VERSION {version}")
+        return version
 
 
 class ContentStore:
