@@ -17,14 +17,16 @@ from PIL import Image
 # local
 from py4ami.ami_bib import Publication
 
-from py4ami.ami_pdf import SVG_NS, SVGX_NS, CSSStyle, PDFArgs, PDFDebug
+from py4ami.ami_pdf import SVG_NS, SVGX_NS, PDFArgs, PDFDebug
 from py4ami.ami_pdf import AmiPage, X, Y, SORT_XY, PDFImage
 from py4ami.ami_pdf import WORDS, IMAGES, ANNOTS
-from py4ami.ami_html import HtmlUtil, STYLE, FILL, STROKE, FONT_FAMILY, FONT_SIZE
+from py4ami.ami_html import HtmlUtil, STYLE, FILL, STROKE, FONT_FAMILY, FONT_SIZE, CSSStyle
 from py4ami.ami_html import H_SPAN, H_BODY, H_P
 from py4ami.pyamix import PyAMI
 from py4ami.bbox_copy import BBox
+from py4ami.file_lib import FileLib
 from test.resources import Resources
+
 from test.test_all import AmiAnyTest
 
 # class PDFTest:
@@ -54,6 +56,9 @@ OUTDIR = "outdir"
 OUTFORM = "outform"
 OUTPATH = "outpath"
 OUTSTEM = "outstem"
+PDF2HTML = "pdf2html"
+PDFMINER = "pdfminer"
+PDFPLUMBER = "pdfplumber"
 FLOW = "flow"
 # FORMAT = "fmt"
 IMAGEDIR = "imagedir"
@@ -103,6 +108,9 @@ class PDFTest(test.test_all.AmiAnyTest):
     NYI = True and AmiAnyTest.NYI
     USER = True and AmiAnyTest.USER
 
+    #skipIf
+    BUG = True and AmiAnyTest.BUG
+
     VERYLONG = False or AmiAnyTest.VERYLONG
 
     # local
@@ -116,7 +124,6 @@ class PDFTest(test.test_all.AmiAnyTest):
     def test_pdfbox_output_exists(self):
         """check CLIMATE dir exists
         """
-        # assert str(Resources.CLIMATE_10_DIR) == "/Users/pm286/workspace/pyami/test/resources/svg", f"resources {Resources.CLIMATE_10_DIR}"
         assert Resources.CLIMATE_10_PROJ_DIR.exists(), f"{Resources.CLIMATE_10_PROJ_DIR} should exist"
 
     @unittest.skipUnless("enviroment", ADMIN)
@@ -287,7 +294,13 @@ class PDFTest(test.test_all.AmiAnyTest):
 
     @unittest.skipUnless(USER, "page2sect")
     def test_make_ami_pages_with_spans_from_charstream_ipcc_chap6(self):
-        """The central AMI method to make HTML from PDF characters
+        """
+        The central AMI method to make HTML from PDF characters
+
+        creates spans with coordinates inside divs
+        Uses AmiPage.create_html_pages() which uses AmiPage.chars_to_spans()
+        creates Raw HTML
+
         """
         output_stem = "chap6"
         page_nos = range(3, 13)
@@ -569,7 +582,7 @@ class PDFTest(test.test_all.AmiAnyTest):
     def test_bmp_png_to_png(self):
         """
         convert bmp, jpgs, etc to PNG
-        results in temp_oldx/ipcc_chap6/png/
+        results in temp/ipcc_chap6/png/
         checks existence on created PNG
         uses: pdf_image.convert_all_suffixed_files_to_target(dirx, [".bmp", ".jpg"], ".png", outdir=outdir)
         USEFUL
@@ -756,17 +769,23 @@ LTPage
                     pdf_debug.debug_page_properties(page, debug=options)
 
     def test_make_structured_html_MAIN(self):
-        """structures the flat HTML from pdfplumber, but no coordinates
-        Can still be used for word frequency, etc."""
+        """
+        structures the flat HTML from pdfplumber, but no coordinates
+        Can still be used for word frequency, etc.
+        USER
+        uses tidy_flow()
+        """
 
         print(f" converting {IPCC_CHAP6_PDF}")
         assert IPCC_CHAP6_PDF.exists(), f"chap6 {IPCC_CHAP6_PDF}"
         pdf_args = PDFArgs()
         pdf_args.arg_dict[INPATH] = IPCC_CHAP6_PDF
         pdf_args.arg_dict[MAXPAGE] = 10
+        pdf_args.arg_dict[PAGES] = "1_10"
+        pdf_args.arg_dict[OUTPATH] = Path(Resources.IPCC_TEMP_CHAP06, "pdf.html")
 
         print(f"arg_dict {pdf_args.arg_dict}")
-        outfile = pdf_args.convert_write()
+        outfile, _ = pdf_args.convert_write()
         if not outfile:
             print(f"no file written")
         else:
@@ -775,8 +794,10 @@ LTPage
 
     @unittest.skipUnless(HTML, "create running text")
     @unittest.skipUnless(USER, "develop for commandline")
-    def test_make_structured_html_pages_MAIN(self):
+    # @unittest.skipIf(BUG, "bad parsing of page ranges")
+    def test_convert_to_raw_html_chap6_maxpage(self):
         """structures the flat HTML from pdfplumber into a running stream, but no coordinates
+        the only test that uses tidy_flow()
         Can still be used for word frequency, etc.
 
 Uses:
@@ -785,27 +806,75 @@ Uses:
     if self.flow:
         self.html = self.tidy_flow()
 
+        creates single file ~/pyami/temp/ipcc_chap6/flow.test4.html (concatenated pages in WRONG ORDER)
+        /pyami/temp/ipcc_chap6/chapter_6:.html - seems to be Chapter/author page.
+
+
         """
 
         # print(f" converting {IPCC_CHAP6_PDF}")
         assert IPCC_CHAP6_PDF.exists(), f"chap6 {IPCC_CHAP6_PDF}"
         pdf_args = PDFArgs()
-        pdf_args.arg_dict[MAXPAGE] = 4
+        maxpage = 5
+        pdf_args.arg_dict[MAXPAGE] = maxpage  #works
         pdf_args.arg_dict[INPATH] = IPCC_CHAP6_PDF
-        pdf_args.arg_dict[OUTPATH] = Path(Resources.TEMP_DIR,  "ipcc_chap6", "flow.test.html")
+        IPCC_TEMP_CHAP6 = Path(Resources.TEMP_DIR, "ipcc_chap6")
+        pdf_args.arg_dict[OUTPATH] = Path(IPCC_TEMP_CHAP6, f"flow.test{maxpage}.html")
+        pdf_args.arg_dict[PDF2HTML] = PDFPLUMBER
 
         pprint.pprint(pdf_args.arg_dict)
         # pdf_args.arg_dict[PAGES] = [(1,3), (5,10)]
 
         print(f"arg_dict {pdf_args.arg_dict}")
-        outfile = Path(pdf_args.convert_write())
+        outfile, _ = pdf_args.convert_write()  # all the conversion happens here
+        assert Path(outfile).exists()
+        assert str(outfile).endswith(f"temp/ipcc_chap6/flow.test{maxpage}.html")
         if not outfile:
             print(f"no file written")
         else:
             print(f"check {outfile.absolute()} exists")
             assert outfile.exists(), f"outfile {outfile} should exist"
+            size = outfile.stat().st_size
+            if maxpage == 4:
+                assert size > 15000, f"size {outfile} {size}"
 
-    @unittest.skipIf(NYI, "no code yet")
+    @unittest.skipUnless(CMD, "command")
+    def test_convert_to_raw_html_chap6_page_ranges(self):
+        """
+        converts complete chapter to raw HTML.
+        outputs each page as
+        .../pyami/temp/ipcc_chap6/fulltext.flow_5.html
+        and also concatenates into .../pyami/temp/ipcc_chap6/flow.test.html
+        If --maxpage or --pages is used then only output specific pages
+        --maxpage is obsolete
+
+        DOES NOT CREATE FLOW YET.
+
+
+        """
+        outfile = Path(Resources.IPCC_TEMP_CHAP06, "all.html")
+        # args = f"PDF --infile {IPCC_CHAP6_PDF} --pages _2 5_7 9 11_15 217_ --offset 0 --outdir {Resources.IPCC_TEMP_CHAP06}"
+        # args = f"PDF --infile {IPCC_CHAP6_PDF} --pages _2 5_7 --offset 0 --outdir {Resources.IPCC_TEMP_CHAP06} --pdf2html pdfplumber"
+        # args = f"PDF --infile {IPCC_CHAP6_PDF} --pages _2 5_7 --offset 0 --outdir {Resources.IPCC_TEMP_CHAP06} --pdf2html pdfminer"
+        args = f"PDF --infile {IPCC_CHAP6_PDF} --outdir {Resources.IPCC_TEMP_CHAP06} --pages 3_5 --flow True --outpath {outfile} --pdf2html pdfplumber"
+        PyAMI().run_command(args)
+        print(f"created outfile {outfile}")
+        # assert outfile.exists(), f"{outfile} should exist"
+
+    def test_extract_single_page_ipcc_toc_chap6(self):
+        """
+        extract a single page which is the TableOfContents
+
+        """
+        assert Path(IPCC_CHAP6_PDF).exists(), f"expected {IPCC_CHAP6_PDF}"
+        assert Path(Resources.IPCC_TEMP_CHAP06).exists(), f"expected {Resources.IPCC_TEMP_CHAP06}"
+
+        args = f"PDF --infile {IPCC_CHAP6_PDF} --pages 4 --outdir {Resources.IPCC_TEMP_CHAP06} --flow True"
+        PyAMI().run_command(args)
+        outpath = Path(Resources.IPCC_TEMP_CHAP06, "fulltext.flow_4.html")
+        assert outpath.exists(), f"{outpath} should be created"
+
+    @unittest.skipIf(LONG, "doesn't obey --maxpage or --pages")
     def test_make_structured_html_cmdline_DEBUG(self):
         """
         Previous one gives:
@@ -826,22 +895,48 @@ Uses:
          maxpage=[88], outdir=['/Users/pm286/projects/semanticClimate/ipcc/ar6/wg3/Chapter02/'],
          outform='html', outstem='fulltext.flow', resolution=400, template=None)"""
 
+        """
+        python -m py4ami.pyamix PDF --inpath /Users/pm286/projects/semanticClimate/ipcc/ar6/wg3/Chapter17.pdf --outdir /Users/pm286/projects/semanticClimate/ipcc/ar6/wg3/Chapter17/raw/"""
+        args = " PDF --inpath /Users/pm286/projects/semanticClimate/ipcc/ar6/wg3/Chapter17.pdf" \
+               " --outdir /Users/pm286/projects/semanticClimate/ipcc/ar6/wg3/Chapter17/raw/" \
+               " --pages 1_4"
+
+        pyami = PyAMI()
+        pyami.run_command(args)
+
+    def test_pdf_help(self):
+        args = "PDF"
+        pyami = PyAMI()
+        pyami.run_command(args)
+
     def test_make_ipcc_html_spans(self):
-        """uses PDFMiner library (no coordinates I think)"""
-        sem_clim_dir = Path("/users/pm286", "projects", "semanticClimate")
-        if not sem_clim_dir.exists():
-            print(f"no ipcc dir {sem_clim_dir}, so skipping")
-            return
-        ipcc_dir = Path(sem_clim_dir, "ipcc", "ar6", "wg3")
-        assert ipcc_dir.exists(), f"ipcc_dir {ipcc_dir} does not exist"
+        """
+        read some/all PDF pages in chapter
+        parse with pdfplumber into raw_html
+
+        uses PDFMiner library (no coordinates I think)
+        then
+        uses flow_tidy() to determine pages, wrap lines (span/div) in pages
+        join pages
+        trim headers and footers and sides
+        then
+        creates and HtmlTidy to remove or edit unwanted span/div/br
+
+
+        USED
+        MODEL
+        """
+
         chapter = "Chapter04"
+        ipcc_dir = Path(Resources.IPCC_DIR)
         print(f"Converting chapter: {chapter}")
-        pdf_args = PDFArgs()
+        pdf_args = PDFArgs() # also supports commands
         chapter_dir = Path(ipcc_dir, chapter)
+        # populate arg commands
         pdf_args.arg_dict[INDIR] = chapter_dir
         assert pdf_args.arg_dict[INDIR].exists(), f"dir does not exist {chapter_dir}"
-        inpath = Path(chapter, "fulltext.pdf")
-        pdf_args.arg_dict[INPATH] = Path(chapter_dir, "fulltext.pdf")
+        inpath = Path(chapter_dir, "fulltext.pdf")
+        pdf_args.arg_dict[INPATH] = inpath
         assert pdf_args.arg_dict[INPATH].exists(), f"file does not exist {inpath}"
         pdf_args.arg_dict[MAXPAGE] = 20
         pdf_args.arg_dict[OUTFORM] = "flow.html"
@@ -849,6 +944,7 @@ Uses:
         if not outdir.exists():
             outdir.mkdir()
         pdf_args.arg_dict[OUTDIR] = outdir
+        pdf_args.arg_dict[OUTPATH] = Path(outdir, "ipcc_spans.html")
         print(f"arg_dict {pdf_args.arg_dict}")
 
         pdf_args.unwanteds = {
@@ -869,12 +965,11 @@ Uses:
                 "regex": "^\\s*(IPCC AR6 WGIII)|(IPCC WGIII AR6)\\s*$",
             },
         }
-        pdf_args.convert_write()
+        _,_ = pdf_args.convert_write() # refactor, please
 
     @unittest.skipUnless(VERYLONG, "processes Chapters 04, 05, 16, 17")
     def test_make_ipcc_html(self):
-        """
-        """
+        """not really a test"""
         sem_clim_dir = Path("/users/pm286", "projects", "semanticClimate")
         if not sem_clim_dir.exists():
             print(f"no ipcc dir {sem_clim_dir}, so skipping")
@@ -1007,7 +1102,7 @@ LTPage
 
     def test_convert_pdf_to_html_and_save(self):
         """Uses PDFArgs.convert_pdf to convert PDF to HTML and save
-        to temp_oldx (/Users/pm286/workspace/pyami/temp_oldx/html/pmc4121.xml)
+        to temp (/Users/pm286/workspace/pyami/temp/html/pmc4121.xml)
         This is raw output with <br> between lines and mirrors the layout of 
         """
         # Use `pip3 install pdfminer.six` for python3
@@ -1057,11 +1152,29 @@ LTPage
             ['PDF', '--inpath', str(inpath), '--outdir', str(outdir), '--pages', '_2', '4', '6_8', '11_'])
 
     def test_subcommands_maxpage(self):
+        """
+        USER
+         COMMAND
+         PDF2HTML (but doesn't yet work)
+
+         for Manny
+        """
         # run args
-        inpath = Path(Resources.PDFS_DIR, "1758-2946-3-44.pdf")
-        outdir = Path(Resources.TEMP_DIR, "pdf", "1758-2946-3-44")
+
+        inpath = Path(Resources.IPCC_CHAP06, "fulltext.pdf")
+        outdir = Path(Resources.IPCC_TEMP_CHAP06)
+        htmls = FileLib.delete_files(outdir, "*.html")
+        out2 = Path(outdir, "fulltext.flow_2.html")
+        assert not out2.exists()
         PyAMI().run_command(
-            ['PDF', '--inpath', str(inpath), '--outdir', str(outdir), "--maxpage", "3"])
+            ['PDF', '--inpath', str(inpath), '--outdir', str(outdir),
+             "--pdf2html", "pdfplumber", "--pages", "1_3", "--flow", "True"])
+        files = FileLib.list_files(outdir, "*.html")
+        assert len(files) == 3
+#        assert FileLib.size(out2) > 5000 # files may be empty
+
+
+
 
     #    @unittest.skipUnless("old test", self.admin)
     def test_cannot_iterate(self):
@@ -1074,6 +1187,198 @@ LTPage
         PyAMI().run_command(
             ['PDF', '--help'])
 
+class PDF_SVGTest(test.test_all.AmiAnyTest):
+
+    # all are skipUnless
+    ADMIN = True and AmiAnyTest.ADMIN
+    CMD = True and AmiAnyTest.CMD
+    DEBUG = True and AmiAnyTest.DEBUG
+    LONG = True and AmiAnyTest.LONG
+    NET = True and AmiAnyTest.NET
+    OLD = True and AmiAnyTest.OLD
+    NYI = True and AmiAnyTest.NYI
+    USER = True and AmiAnyTest.USER
+
+    SVG = True
+
+    def make_full_chap_10_draft_html_from_svg(pretty_print, use_lines, rotated_text=False):
+        """
+        reads SVG output from ami3/pdfbox and converts to HTML
+        used by several tests at present and will be intergrated
+        :param pretty_print: pretty print the HTML. Warning may introduce whitespace
+        :param use_lines: output is CompositeLines. Not converted into running text (check)
+        :param rotated_text: include/ignore tex# ts with non-zero @rotateDegress attribute
+        """
+        if not Path(FINAL_DRAFT_DIR, f"fulltext-page.2912.svg").exists():
+            raise Exception("must have SVG from ami3")
+        for page_index in CURRENT_RANGE:
+            page_path = Path(FINAL_DRAFT_DIR, f"fulltext-page.{page_index}.svg")
+            html_path = Path(Resources.CLIMATE_10_HTML_TEMP_DIR, f"page.{page_index}.html")
+            if not Resources.CLIMATE_10_HTML_TEMP_DIR.exists():
+                Resources.CLIMATE_10_HTML_TEMP_DIR.mkdir()
+            ami_page = AmiPage.create_page_from_svg(page_path, rotated_text=rotated_text)
+            ami_page.write_html(html_path, pretty_print, use_lines)
+
+    @unittest.skipUnless("enviroment", ADMIN)
+    def test_findall_svg_and_find_texts(self):
+        """find climate10_:text elements
+        """
+        assert PAGE_9.exists(), f"{PAGE_9} should exist"
+        page9_elem = lxml.etree.parse(str(PAGE_9))
+        texts = page9_elem.findall(f"//{{{SVG_NS}}}text")
+        assert len(texts) == 108
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_get_text_attribs(self):
+        """find various SVG attributes, including 'style'
+        """
+        ami_page = AmiPage.create_page_from_svg(PAGE_9)
+        # <climate10_:text> element
+        text0 = ami_page.get_svg_text(0)
+        assert text0.svg_text_elem.tag == f"{{{SVG_NS}}}text"
+        # single Y-coord
+        assert text0.svg_text_elem.attrib.get(Y) == '44.76'
+        # list of X-coords
+        assert text0.svg_text_elem.attrib.get(X) == \
+               '72.0,79.201,84.721,90.241,96.961,104.162,111.363,117.482,124.798,127.288,258.242,263.762,268.' \
+               '802,276.601,284.401,288.841,292.202,297.241,299.761,303.001,308.041,311.402,313.921,319.441,' \
+               '324.481,327.241,330.001,334.441,339.481,347.28,351.601,356.641,361.081,364.442,368.28,370.77,' \
+               '448.08,451.439,456.96,463.563,470.167,472.687,480.006,486.61,491.651,494.171,503.533,510.718,' \
+               '513.238,516.594,519.951,523.307'
+        # list of character-widths (from publisher) (multiply by font-size to get pixels)
+        assert text0.svg_text_elem.attrib.get(f"{{{SVGX_NS}}}width") == \
+               '0.72,0.56,0.56,0.67,0.72,0.72,0.61,0.72,0.25,0.55,0.56,0.5,0.78,0.78,0.44,0.33,0.5,0.25,0.33,' \
+               '0.5,0.33,0.25,0.56,0.5,0.28,0.28,0.44,0.5,0.78,0.44,0.5,0.44,0.33,0.39,0.25,0.55,0.33,0.56,' \
+               '0.67,0.67,0.25,0.72,0.67,0.5,0.25,0.94,0.72,0.25,0.33,0.33,0.33,0.25'
+        # style (dict-like collection of name-value pairs
+        assert text0.svg_text_elem.get(STYLE) == \
+               'fill:rgb(0,0,0);font-family:TimesNewRomanPSMT;font-size:9.96px;stroke:none;'
+        # text-content without tags
+        text_content = text0.get_text_content()
+        assert text_content == "APPROVED Summary for Policymakers IPCC AR6 WG III "
+        assert len(text_content) == 50  # some spaces have been elided??
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_get_text_attrib_vals(self):
+        """more attributes and convenience methods"""
+        ami_page = AmiPage.create_page_from_svg(PAGE_9)
+        # <climate10_:text> element
+        ami_text0 = ami_page.get_svg_text(0)
+        x_coords = ami_text0.get_x_coords()
+        assert x_coords == [
+            72.0, 79.201, 84.721, 90.241,
+            96.961, 104.162, 111.363, 117.482, 124.798, 127.288, 258.242, 263.762, 268.802,
+            276.601, 284.401, 288.841, 292.202, 297.241, 299.761,
+            303.001, 308.041, 311.402, 313.921, 319.441, 324.481, 327.241, 330.001,
+            334.441, 339.481, 347.28, 351.601, 356.641, 361.081, 364.442,
+            368.28, 370.77, 448.08, 451.439, 456.96, 463.563, 470.167,
+            472.687, 480.006, 486.61, 491.651, 494.171, 503.533, 510.718, 513.238, 516.594, 519.951, 523.307]
+        assert len(x_coords) == 52
+
+        widths = ami_text0.get_widths()
+        assert widths == [
+            0.72, 0.56, 0.56, 0.67, 0.72, 0.72, 0.61,
+            0.72, 0.25, 0.55, 0.56, 0.5, 0.78, 0.78, 0.44, 0.33, 0.5, 0.25, 0.33, 0.5, 0.33,
+            0.25, 0.56, 0.5, 0.28, 0.28, 0.44, 0.5, 0.78, 0.44, 0.5, 0.44, 0.33,
+            0.39, 0.25, 0.55, 0.33, 0.56, 0.67, 0.67, 0.25, 0.72, 0.67, 0.5, 0.25, 0.94, 0.72, 0.25, 0.33, 0.33,
+            0.33, 0.25
+        ]
+        assert len(widths) == 52
+
+        # SVG style dict from SVG@style attribute
+        style_dict = ami_text0.extract_style_dict_from_svg()
+        # assert style_dict == {'fill': 'rgb(0,0,0)',\n 'font-family': 'TimesNewRomanPSMT',\n 'font-size': '9.96px',\n 'stroke': 'none'}
+        assert style_dict[FILL] == 'rgb(0,0,0)'
+        assert style_dict[FONT_FAMILY] == 'TimesNewRomanPSMT'
+        assert style_dict[FONT_SIZE] == '9.96px'
+        assert style_dict[STROKE] == 'none'
+        assert ami_text0.get_font_size() == 9.96
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_create_text_lines_page6(self):
+        """creation of AmiPage from SVG page and creation of text spans"""
+        page = AmiPage.create_page_from_svg(PAGE_6)
+        page.create_text_spans(sort_axes=SORT_XY)
+        assert 70 >= len(page.text_spans) >= 60
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_create_html_from_svg(self):
+        """
+        Test 10 pages
+        """
+        pretty_print = True
+        use_lines = True
+        svg_dir = Resources.CLIMATE_10_SVG_DIR
+        html_dir = Resources.CLIMATE_10_HTML_TEMP_DIR
+        for page_index in range(1, 9):
+            page_path = Path(svg_dir, f"fulltext-page.{page_index}.svg")
+            html_path = Path(html_dir, f"page.{page_index}.html")
+            if not html_dir.exists():
+                html_dir.mkdir()
+            ami_page = AmiPage.create_page_from_svg(page_path)
+            ami_page.write_html(html_path, pretty_print, use_lines)
+            assert html_path.exists(), f"{html_path} exists"
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_create_html_in_selection_from_svg(self):
+        """
+        Test 10 pages
+        """
+        pretty_print = True
+        use_lines = True
+        # selection = range(1, 2912)
+        page_selection = range(1, 50)
+        counter = 0
+        counter_tick = 20
+        html_out_dir = Resources.CLIMATE_10_HTML_TEMP_DIR
+        for page_index in page_selection:
+            if counter % counter_tick == 0:
+                print(f".", end="")
+            page_path = Path(FINAL_DRAFT_DIR, f"fulltext-page.{page_index}.svg")
+            html_path = Path(html_out_dir, f"page.{page_index}.html")
+            if not html_out_dir.exists():
+                html_out_dir.mkdir()
+            ami_page = AmiPage.create_page_from_svg(page_path, rotated_text=False)
+            ami_page.write_html(html_path, pretty_print, use_lines)
+            counter += 1
+            assert html_path.exists(), f"{html_path} exists"
+
+    @unittest.skipUnless(SVG, "svg")
+    def test_create_chapters_through_svg(self):
+        pretty_print = True
+        use_lines = True
+        self.make_full_chap_10_draft_html_from_svg(pretty_print, use_lines)
+        selection = CURRENT_RANGE
+        temp_dir = Resources.CLIMATE_10_HTML_TEMP_DIR
+        for page_index in selection:
+            html_path = Path(temp_dir, f"page.{page_index}.html")
+            with open(html_path, "r") as h:
+                xml = h.read()
+            root = lxml.etree.fromstring(xml)
+            spans = root.findall(f"./{H_BODY}/{H_P}/{H_SPAN}")
+            assert type(spans[0]) is lxml.etree._Element, f"expected str got {type(spans[0])}"
+            assert len(HtmlUtil.get_text_content(spans[0])) > 0
+            span = None
+            chapter = ""
+            # bug in parsing line 0
+            if Publication.is_chapter_or_tech_summary(HtmlUtil.get_text_content(spans[0])):
+                span = spans[0]
+            if span is None and Publication.is_chapter_or_tech_summary(HtmlUtil.get_text_content(spans[1])):
+                span = spans[1]
+            if span is None:
+                print(f"p:{page_index}, {HtmlUtil.get_text_content(spans[0])}, {HtmlUtil.get_text_content(spans[1])}")
+            else:
+                chapter = HtmlUtil.get_text_content(span)
+                print("CHAP ", chapter)
+
+    @unittest.skip("obsolete")
+    @unittest.skipUnless(SVG, "svg")
+    @unittest.skipUnless(CMD, "command")
+    def test_svg2page(self):
+        proj = Resources.CLIMATE_10_PROJ_DIR
+        args = f"--proj {proj} --apply svg2page"
+        PyAMI().run_command(args)
+
     # =====================================================================================================
     # =====================================================================================================
 
